@@ -43,14 +43,14 @@ macro_rules! declare_name {
                 // See the `respan!` macro for more details.
                 // This should use `crate::respan!` once
                 // https://github.com/rust-lang/rust/pull/72121 is merged:
-                // see https://github.com/solana-labs/solana/issues/10933.
-                // For now, we need to use `::solana_sdk`
+                // see https://github.com/fair-exchange/safecoin/issues/10933.
+                // For now, we need to use `::safecoin_sdk`
                 //
                 // `respan!` respans the path `$crate::id`, which we then call (hence the extra
                 // parens)
                 (
                     stringify!($filename).to_string(),
-                    ::solana_sdk::respan!($crate::$id, $name)(),
+                    ::safecoin_sdk::respan!($crate::$id, $name)(),
                 )
             };
         }
@@ -86,17 +86,15 @@ macro_rules! declare_name {
 /// # // wrapper is used so that the macro invocation occurs in the item position
 /// # // rather than in the statement position which isn't allowed.
 /// # mod item_wrapper {
-/// use solana_sdk::{
+/// use safecoin_sdk::{
 ///     declare_program,
 ///     instruction::InstructionError,
-///     keyed_account::KeyedAccount,
 ///     process_instruction::InvokeContext,
 ///     pubkey::Pubkey,
 /// };
 ///
 /// fn my_process_instruction(
 ///     program_id: &Pubkey,
-///     keyed_accounts: &[KeyedAccount],
 ///     instruction_data: &[u8],
 ///     invoke_context: &mut dyn InvokeContext,
 /// ) -> Result<(), InstructionError> {
@@ -111,7 +109,7 @@ macro_rules! declare_name {
 /// );
 ///
 /// # }
-/// # use solana_sdk::pubkey::Pubkey;
+/// # use safecoin_sdk::pubkey::Pubkey;
 /// # use item_wrapper::id;
 /// let my_id = Pubkey::from_str("My11111111111111111111111111111111111111111").unwrap();
 /// assert_eq!(id(), my_id);
@@ -121,17 +119,15 @@ macro_rules! declare_name {
 /// # // wrapper is used so that the macro invocation occurs in the item position
 /// # // rather than in the statement position which isn't allowed.
 /// # mod item_wrapper {
-/// use solana_sdk::{
+/// use safecoin_sdk::{
 ///     declare_program,
 ///     instruction::InstructionError,
-///     keyed_account::KeyedAccount,
 ///     process_instruction::InvokeContext,
 ///     pubkey::Pubkey,
 /// };
 ///
 /// fn my_process_instruction(
 ///     program_id: &Pubkey,
-///     keyed_accounts: &[KeyedAccount],
 ///     instruction_data: &[u8],
 ///     invoke_context: &mut dyn InvokeContext,
 /// ) -> Result<(), InstructionError> {
@@ -140,14 +136,14 @@ macro_rules! declare_name {
 /// }
 ///
 /// declare_program!(
-///     solana_sdk::system_program::ID,
+///     safecoin_sdk::system_program::ID,
 ///     solana_my_program,
 ///     my_process_instruction
 /// );
 /// # }
 ///
 /// # use item_wrapper::id;
-/// assert_eq!(id(), solana_sdk::system_program::ID);
+/// assert_eq!(id(), safecoin_sdk::system_program::ID);
 /// ```
 #[macro_export]
 macro_rules! declare_program(
@@ -158,11 +154,10 @@ macro_rules! declare_program(
         #[no_mangle]
         pub extern "C" fn $name(
             program_id: &$crate::pubkey::Pubkey,
-            keyed_accounts: &[$crate::keyed_account::KeyedAccount],
             instruction_data: &[u8],
             invoke_context: &mut dyn $crate::process_instruction::InvokeContext,
         ) -> Result<(), $crate::instruction::InstructionError> {
-            $entrypoint(program_id, keyed_accounts, instruction_data, invoke_context)
+            $entrypoint(program_id, instruction_data, invoke_context)
         }
     )
 );
